AccessMode

Enum AccessMode 

pub enum AccessMode {
    RO,
    WO,
    RW,
}
Access privileges for a GenICam node as described in the XML.

Variants



RO

Read-only node. The underlying register must not be modified by the client.



WO

Write-only node. Reading the register is not permitted.



RW

Read-write node. The register may be read and written by the client.