parse

Function parse 

pub fn parse(xml: &str) -> Result<XmlModel, XmlError>
Parse a GenICam XML document into an XmlModel.

The parser only understands a practical subset of the schema. Unknown tags are skipped which keeps the implementation forward compatible with richer documents.